================
NiChart_Harmonize
================

Harmonization tools for multi-site neuroimaging analysis.

contact: guray (dot) erus (at) pennmedicine (dot) upenn (dot) edu

Overview
---------

This package extends the functionality of the package developed by Nick Cullen [2]_,
``neuroCombat``.

Installation
------------

Latest version: ``nh_v4.1`` (01/10/2023)

Requirements:

* ``git >= 2.17.2``
* ``python >= 3.6.8``

Installation (with optional conda environment):
-----------------------------------------------

> git clone https://github.com/gurayerus/NiChartHarmonize

> cd NiChartHarmonize

> conda create -n NH python=3

> conda activate NH

> pip install .


Usage:
------
See test_temp/README.txt



